# Tutorials

This section contains practical examples demonstrating how to use phasecurvefit.

::::{grid} 1 2 2 3
:gutter: 2

:::{grid-item-card} Stream Autoencoder
:link: stream_autoencoder
:link-type: doc

[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/GalacticDynamics/phasecurvefit/blob/main/docs/tutorials/stream_autoencoder.ipynb)
:::

:::{grid-item-card} Stream Running Mean Path
:link: stream_runningmean
:link-type: doc

[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/GalacticDynamics/phasecurvefit/blob/main/docs/tutorials/stream_runningmean.ipynb)
:::

:::{grid-item-card} Epitrochoid Autoencoder
:link: epitrochoid_autoencoder
:link-type: doc

[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/GalacticDynamics/phasecurvefit/blob/main/docs/tutorials/epitrochoid_autoencoder.ipynb)
:::

:::{grid-item-card} Epitrochoid Running Mean Path
:link: epitrochoid_runningmean
:link-type: doc

[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/GalacticDynamics/phasecurvefit/blob/main/docs/tutorials/epitrochoid_runningmean.ipynb)
:::

::::

```{toctree}
:maxdepth: 1
:hidden:

stream_autoencoder
stream_runningmean
epitrochoid_autoencoder
epitrochoid_runningmean
```
